API Documentation
=================

See http://docs.opennebula.org/4.10/integration/system_interfaces/api.html

.. toctree::
   :maxdepth: 2

   api/client
   api/host
   api/image
   api/vn
   api/user
   api/group
   api/template
   api/vm

